@@ -1,17 +1,17 @@
 """pytest_cache_assert."""
 
 from ._check_assert.assert_config import AssertConfig  # noqa: F401
+from ._check_assert.assert_rules import (  # noqa: F401
+    AssertRule, Comparator, Wild, check_exact, check_suppress,
+    check_type, gen_check_date_proximity, gen_check_date_range,
+)
 from ._check_assert.cache_store import CacheStoreType, LocalJSONCacheStore  # noqa: F401
 from ._check_assert.config import CacheAssertContainerKeys, retrieve  # noqa: F401
-from ._check_assert.constants import Wildcards  # noqa: F401
 from ._check_assert.converter import Converter  # noqa: F401
 from ._check_assert.error_message import NoCacheError  # noqa: F401
-from ._check_assert.key_rules import (  # noqa: F401
-    Comparator, KeyRule, check_exact, check_suppress, check_type, gen_check_date_proximity, gen_check_date_range,
-)
 from ._check_assert.validator import DictDiffValidator, ValidatorType  # noqa: F401
 
-__version__ = '2.0.0'
+__version__ = '3.0.0'
 __pkg_name__ = 'pytest_cache_assert'
 
 # ====== Above is the recommended code from calcipy_template and may be updated on new releases ======
