@@ -4,18 +4,17 @@ import inspect
 import json
 import re
 from collections import defaultdict
+from contextlib import suppress
 from enum import Enum
 from json import JSONEncoder
 from pathlib import Path, PurePath
 from uuid import UUID
 
-from attrs import field, mutable
-from attrs_strict import type_validator
 from beartype import beartype
 from beartype.typing import Any, Callable, Dict, List, Pattern, Tuple
-from loguru import logger
+from pydantic import BaseModel, Field
 
-from .constants import DIFF_TYPES
+from .constants import T_CONVERTER, T_DIFF
 from .converter import Converter
 
 _RE_MEMORY_ADDRESS = re.compile(r' at 0x[^>]+>')
@@ -23,7 +22,7 @@ _RE_MEMORY_ADDRESS = re.compile(r' at 0x[^>]+>')
 
 
 class Unconvertable(ValueError):
-    """Custom Error to indicate conversion failure"""
+    """Custom Error to indicate conversion failure."""
 
     ...
 
@@ -34,20 +33,19 @@ def replace_memory_address(obj: Any) -> str:
     return _RE_MEMORY_ADDRESS.sub('(..)>', str(obj))  # noqa: PD005
 
 
-@mutable()
-class _Converters:
+class _Converters(BaseModel):
     """Register converters for application."""
 
-    converters: List[Tuple[Any, Callable]] = field(factory=list, validator=type_validator())
-    converter_lookup: Dict[Any, List[Callable]] = field(factory=dict, validator=type_validator())
+    converters: List[Tuple[Any, T_CONVERTER]] = Field(default_factory=list)
+    converter_lookup: Dict[Any, List[T_CONVERTER]] = Field(default_factory=dict)
 
     @beartype
-    def register(self, types: List[Any], converter: Callable) -> None:
+    def register(self, types: List[Any], converter: T_CONVERTER) -> None:
         self.converters.extend((typ, converter) for typ in types)
         self.converter_lookup = {}
 
     @beartype
-    def get_lookup(self) -> Dict[Any, List[Callable]]:
+    def get_lookup(self) -> Dict[Any, List[T_CONVERTER]]:
         if not self.converter_lookup:
             self.converter_lookup = defaultdict(list)
             for typ, converter in self.converters[::-1]:
@@ -78,28 +76,19 @@ class _CacheAssertSerializer(JSONEncoder):
 
         converters = _CONVERTERS.get_lookup().get(type(obj))
         for converter in converters or []:
-            try:
+            with suppress(Unconvertable):
                 return converter(obj)
-            except Unconvertable:
-                ...
-            except Exception as exc:
-                logger.exception(f'Unhandled error: {exc}')
 
         for typ, converters in _CONVERTERS.get_lookup().items():
             if isinstance(obj, typ):
                 for converter in converters:
-                    try:
+                    with suppress(Unconvertable):
                         return converter(obj)
-                    except Unconvertable:
-                        ...
-                    except Exception as exc:
-                        logger.exception(f'Unhandled error: {exc}')
 
-        # Fallback for types that aren't easily convertable
-        try:
+        # Fallback for classes (i.e. `UUID`) that are of type "type" and otherwise cannot be easily registered
+        with suppress(Unconvertable):
             return _generic_memory_address_serializer(obj)
-        except Unconvertable:
-            ...
+
         raise Unconvertable(f'Failed to encode `{obj}` ({type(obj)}) with {_CONVERTERS.get_lookup()}')
 
 
@@ -120,6 +109,16 @@ _CONVERTERS.register([bool, int, float], _no_op)
 
 
 def _serialize_path(obj: Path) -> str:
+    """Attempt to provide a path agnostic of working directory or device."""
+    cwd = Path.cwd()
+    pth = obj
+    with suppress(AttributeError):
+        pth = obj.resolve()  # Attempt to remove ".."
+    # if pth.is_relative_to(cwd):  # PLANNED: Faster to LBYL or EAFP?
+    with suppress(ValueError):
+        return f'--/{pth.relative_to(cwd).as_posix()}'
+    with suppress(ValueError):
+        return f'~/{pth.relative_to(Path.home()).as_posix()}'
     return obj.as_posix()
 
 
@@ -128,7 +127,7 @@ _CONVERTERS.register([Path, PurePath], _serialize_path)
 
 def _serialize_enum(obj: Enum) -> str:
     try:
-        return obj.value
+        return str(obj.value)
     except AttributeError as exc:
         raise Unconvertable(exc) from None
 
@@ -144,52 +143,44 @@ def _serialize_complex(obj: complex) -> List[float]:
 
 _CONVERTERS.register([complex], _serialize_complex)
 
-try:
+with suppress(ImportError):
     from pendulum.datetime import DateTime
     _CONVERTERS.register([DateTime], str)
-except ImportError:
-    ...
 
+with suppress(ImportError):
+    from arrow import Arrow
+    _CONVERTERS.register([Arrow], str)
 
-try:
+with suppress(ImportError):
     import pandas as pd
 
-    def _serialize_pandas(obj: pd.DataFrame) -> Dict:
-        return obj.to_dict()
+    def _serialize_pandas(obj: pd.DataFrame) -> Dict:  # type: ignore[type-arg]
+        return obj.to_dict()  # type: ignore[no-any-return]
 
     _CONVERTERS.register([pd.DataFrame], _serialize_pandas)
-except ImportError:
-    ...
 
-
-try:
+with suppress(ImportError):
     import numpy as np
 
-    # FIXME: To list?
-
-    def _serialize_numpy(obj: np.ndarray) -> Dict:
-        return obj.tolist()
+    def _serialize_numpy(obj: np.ndarray) -> List:  # type: ignore[type-arg]
+        return obj.tolist()  # type: ignore[no-any-return]
 
     _CONVERTERS.register([np.ndarray], _serialize_numpy)
-except ImportError:
-    ...
 
-try:
+with suppress(ImportError):
     from pydantic.main import BaseModel
 
-    def _serialize_pydantic(obj: BaseModel) -> Dict:
-        return obj.to_dict()
+    def _serialize_pydantic(obj: BaseModel) -> Dict:  # type: ignore[type-arg]
+        return obj.to_dict()  # type: ignore[attr-defined,no-any-return]
 
     _CONVERTERS.register([BaseModel], _serialize_pydantic)
-except ImportError:
-    ...
 
 
 @beartype
 def register_user_converters(converters: List[Converter]) -> None:
     """Register the user-specified converters."""
     for converter in converters:
-        _CONVERTERS.register(converter.types, converter.func)
+        _CONVERTERS.register(converter.types, converter.func)  # type: ignore[arg-type]
 
 
 @beartype
@@ -229,28 +220,28 @@ def pretty_dumps(obj: Any) -> str:
 
 
 @beartype
-def loads(raw: str) -> DIFF_TYPES:
+def loads(raw: str) -> T_DIFF:
     """Deserialize arbitrary JSON data back to Python types.
 
     Args:
         raw: raw string JSON
 
     Returns:
-        DIFF_TYPES: DiffResult-safe data
+        T_DIFF: DiffResults-safe data
 
     """
     return json.loads(raw)
 
 
 @beartype
-def make_diffable(data: Any) -> DIFF_TYPES:
+def make_diffable(data: Any) -> T_DIFF:
     """Convert raw object to diffable types for assertion checks.
 
     Args:
         data: data to serialize
 
     Returns:
-        DIFF_TYPES: DiffResult-safe data
+        T_DIFF: DiffResults-safe data
 
     """
     return loads(dumps(data))
